#
# spec file for package zmusic
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           zmusic
Version:        1.1.11
Release:        2.1
Summary:        ZDoom component library for music handling
License:        GPL-3.0-only
Group:          Development/Libraries/C and C++
URL:            https://zdoom.org/

#Git-Clone:     https://github.com/ZDoom/ZMusic
Source:         https://github.com/ZDoom/ZMusic/archive/%version.tar.gz
Patch1:         system-fluidsynth.patch
Patch2:         system-gme.patch
Patch3:         dumb-dumb.patch
Patch4:         0001-Add-missing-standard-library-includes-fix-build-with.patch
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pkgconf-pkg-config
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(fluidsynth)
BuildRequires:  pkgconfig(libgme)
BuildRequires:  pkgconfig(libmpg123)
BuildRequires:  pkgconfig(sndfile)
BuildRequires:  pkgconfig(zlib)
Suggests:       fluid-soundfont-gm
Suggests:       fluid-soundfont-gs
Suggests:       timidity
Suggests:       timidity-eawpats
# DUMB is modified to read OggVorbis samples
Provides:       bundled(dumb) = 0.9.3

%description
This is the music playback code from gzdoom, which was separated into its own
code repository starting with gzdoom-4.4.0.

%package -n libzmusic1
Summary:        ZDoom component library for music handling
Group:          System/Libraries

%description -n libzmusic1
This is the music playback code from gzdoom, which was separated into its own
code repository starting with gzdoom-4.4.0.

%package devel
Summary:        Headers for the ZMusic library
Group:          Development/Libraries/C and C++
Requires:       libzmusic1 = %version

%description devel
This subpackage contains the headers for the zmusic library, which is ZDoom's
music component library.

%prep
%autosetup -p0 -n ZMusic-%version

%build
# There is handcrafted assembler, which LTO does not play nice with.
%define _lto_cflags %nil

%cmake -DNO_STRIP=1 \
	-DCMAKE_SHARED_LINKER_FLAGS="" \
	-DCMAKE_EXE_LINKER_FLAGS="" -DCMAKE_MODULE_LINKER_FLAGS="" \
	-DINSTALL_DOCS_PATH="%_defaultdocdir/%name" \
	-DDYN_FLUIDSYNTH=OFF \
	-DDYN_SNDFILE=OFF -DDYN_MPG123=OFF
%cmake_build

%install
%cmake_install
b="%buildroot"
# Won't need lite (a subset with no GPL code) in openSUSE.
rm -f "$b/%_libdir"/libzmusiclite*

%post   -n libzmusic1 -p /sbin/ldconfig
%postun -n libzmusic1 -p /sbin/ldconfig

%files -n libzmusic1
%_libdir/libzmusic.so.1*
%license licenses/*

%files devel
%_includedir/*
%_libdir/libzmusic.so
%_libdir/cmake/

%changelog
* Mon Mar 20 2023 Jan Engelhardt <jengelh@inai.de>
- Add 0001-Add-missing-standard-library-includes-fix-build-with.patch
  to make gcc 13 happy.
* Wed Nov 23 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.1.11
  * Added missing check for AMF format in module loader.
  * Fixed EMIDI track designation checks.
- Add system-fluidsynth.patch
* Mon Jul  4 2022 Jan Engelhardt <jengelh@inai.de>
- Drop -msse/-msse2, CPUID guards do not help.
* Thu Jun 23 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.1.9
  * Improve ALSA MIDI backend: No longer exclude builtin MIDI
    passthrough ports
  * Add handling for KeyPress events and avoid calling
    snd_seq_sync_output_queue twice
  * Add a 32-bit float sample type
  * Add a new ZMusic_GetStreamInfoEx function
  * Implement ZMusic_GetStreamInfo using GetStreamInfoEx
  * Better handle various formats in SndFileSong
  * Handle non-int16 samples in dumb_decode_vorbis
  * Add missing GetStreamInfoEx for CDSong
  * Fixes for gus and wildmidi emulation - fixed gus emulation
    not working with DMXGUS and DMXGUSC lump
* Sat May 29 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to release 1.1.8
  * support dynamic loading of FluidSynth 2.2
  * fixed file header in MIDI wave writer
- Drop 0001-made-sndfile-imported-library-global.patch, was merged
* Sat Apr 10 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.1.6
  * Add detection of Opus comment tags in Ogg files.
  * Multiply master volume for module player by 4.
- Add 0001-made-sndfile-imported-library-global.patch,
  dumb-dumb.patch.
* Sat Oct 31 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.1.4
  * MIDS-format MIDI support
  * libADL/libOPN update
* Tue Sep 15 2020 Jan Engelhardt <jengelh@inai.de>
- Demote Recommends to Suggests. Add suggests for Fluidsynth
  as an alternative to EAW (and the OPL mixer that's built-in).
* Wed Jun 10 2020 Jan Engelhardt <jengelh@inai.de>
- Initial package (v1.1.2) for build.opensuse.org
- Added system-gme.patch (carryover from gzdoom.spec; modified)
